#line 4 "dhcpd-lex.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif



#line 9 "dhcpd-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
    
/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define grecs_dhcpdconst const
#else
#define grecs_dhcpdconst
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (grecs_dhcpd_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((grecs_dhcpd_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE grecs_dhcpdrestart(grecs_dhcpdin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(grecs_dhcpd_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct grecs_dhcpd_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t grecs_dhcpd_size_t;
#endif

/* %if-not-reentrant */
extern grecs_dhcpd_size_t grecs_dhcpdleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *grecs_dhcpdin, *grecs_dhcpdout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define grecs_dhcpdless(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_dhcpdtext. */ \
        int grecs_dhcpdless_macro_arg = (n); \
        YY_LESS_LINENO(grecs_dhcpdless_macro_arg);\
		*grecs_dhcpd_cp = (grecs_dhcpd_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(grecs_dhcpd_c_buf_p) = grecs_dhcpd_cp = grecs_dhcpd_bp + grecs_dhcpdless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up grecs_dhcpdtext again */ \
		} \
	while ( 0 )

#define unput(c) grecs_dhcpdunput( c, (grecs_dhcpdtext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct grecs_dhcpd_buffer_state
	{
/* %if-c-only */
	FILE *grecs_dhcpd_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *grecs_dhcpd_ch_buf;		/* input buffer */
	char *grecs_dhcpd_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	grecs_dhcpd_size_t grecs_dhcpd_buf_size;

	/* Number of characters read into grecs_dhcpd_ch_buf, not including EOB
	 * characters.
	 */
	grecs_dhcpd_size_t grecs_dhcpd_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int grecs_dhcpd_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int grecs_dhcpd_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int grecs_dhcpd_at_bol;

    int grecs_dhcpd_bs_lineno; /**< The line count. */
    int grecs_dhcpd_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int grecs_dhcpd_fill_buffer;

	int grecs_dhcpd_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via grecs_dhcpdrestart()), so that the user can continue scanning by
	 * just pointing grecs_dhcpdin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t grecs_dhcpd_buffer_stack_top = 0; /**< index of top of stack. */
static size_t grecs_dhcpd_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * grecs_dhcpd_buffer_stack = 0; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (grecs_dhcpd_buffer_stack) \
                          ? (grecs_dhcpd_buffer_stack)[(grecs_dhcpd_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (grecs_dhcpd_buffer_stack)[(grecs_dhcpd_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */

/* grecs_dhcpd_hold_char holds the character lost when grecs_dhcpdtext is formed. */
static char grecs_dhcpd_hold_char;
static grecs_dhcpd_size_t grecs_dhcpd_n_chars;		/* number of characters read into grecs_dhcpd_ch_buf */
grecs_dhcpd_size_t grecs_dhcpdleng;

/* Points to current character in buffer. */
static char *grecs_dhcpd_c_buf_p = (char *) 0;
static int grecs_dhcpd_init = 0;		/* whether we need to initialize */
static int grecs_dhcpd_start = 0;	/* start state number */

/* Flag which is used to allow grecs_dhcpdwrap()'s to do buffer switches
 * instead of setting up a fresh grecs_dhcpdin.  A bit of a hack ...
 */
static int grecs_dhcpd_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void grecs_dhcpdrestart (FILE *input_file  );
void grecs_dhcpd_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE grecs_dhcpd_create_buffer (FILE *file,int size  );
void grecs_dhcpd_delete_buffer (YY_BUFFER_STATE b  );
void grecs_dhcpd_flush_buffer (YY_BUFFER_STATE b  );
void grecs_dhcpdpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void grecs_dhcpdpop_buffer_state (void );

static void grecs_dhcpdensure_buffer_stack (void );
static void grecs_dhcpd_load_buffer_state (void );
static void grecs_dhcpd_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER grecs_dhcpd_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE grecs_dhcpd_scan_buffer (char *base,grecs_dhcpd_size_t size  );
YY_BUFFER_STATE grecs_dhcpd_scan_string (grecs_dhcpdconst char *grecs_dhcpd_str  );
YY_BUFFER_STATE grecs_dhcpd_scan_bytes (grecs_dhcpdconst char *bytes,grecs_dhcpd_size_t len  );

/* %endif */

void *grecs_dhcpdalloc (grecs_dhcpd_size_t  );
void *grecs_dhcpdrealloc (void *,grecs_dhcpd_size_t  );
void grecs_dhcpdfree (void *  );

#define grecs_dhcpd_new_buffer grecs_dhcpd_create_buffer

#define grecs_dhcpd_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        grecs_dhcpdensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_dhcpd_create_buffer(grecs_dhcpdin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_is_interactive = is_interactive; \
	}

#define grecs_dhcpd_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        grecs_dhcpdensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_dhcpd_create_buffer(grecs_dhcpdin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_at_bol)

/* %% [1.0] grecs_dhcpdtext/grecs_dhcpdin/grecs_dhcpdout/grecs_dhcpd_state_type/grecs_dhcpdlineno etc. def's & init go here */
/* Begin user sect3 */

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

FILE *grecs_dhcpdin = (FILE *) 0, *grecs_dhcpdout = (FILE *) 0;

typedef int grecs_dhcpd_state_type;

extern int grecs_dhcpdlineno;

int grecs_dhcpdlineno = 1;

extern char *grecs_dhcpdtext;
#ifdef grecs_dhcpdtext_ptr
#undef grecs_dhcpdtext_ptr
#endif
#define grecs_dhcpdtext_ptr grecs_dhcpdtext

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static grecs_dhcpd_state_type grecs_dhcpd_get_previous_state (void );
static grecs_dhcpd_state_type grecs_dhcpd_try_NUL_trans (grecs_dhcpd_state_type current_state  );
static int grecs_dhcpd_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void grecs_dhcpd_fatal_error (grecs_dhcpdconst char msg[]  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up grecs_dhcpdtext.
 */
#define YY_DO_BEFORE_ACTION \
	(grecs_dhcpdtext_ptr) = grecs_dhcpd_bp; \
/* %% [2.0] code to fiddle grecs_dhcpdtext and grecs_dhcpdleng for grecs_dhcpdmore() goes here \ */\
	grecs_dhcpdleng = (size_t) (grecs_dhcpd_cp - grecs_dhcpd_bp); \
	(grecs_dhcpd_hold_char) = *grecs_dhcpd_cp; \
	*grecs_dhcpd_cp = '\0'; \
/* %% [3.0] code to copy grecs_dhcpdtext_ptr to grecs_dhcpdtext[] goes here, if %array \ */\
	(grecs_dhcpd_c_buf_p) = grecs_dhcpd_cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 29
#define YY_END_OF_BUFFER 30
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct grecs_dhcpd_trans_info
	{
	flex_int32_t grecs_dhcpd_verify;
	flex_int32_t grecs_dhcpd_nxt;
	};
static grecs_dhcpdconst flex_int16_t grecs_dhcpd_accept[111] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       30,   28,   25,   26,   27,   28,    4,   15,   15,   14,
       14,   14,   25,    4,   29,   29,   22,   24,   29,   29,
       10,   11,   29,   12,   13,   25,    0,   19,   16,    0,
        4,    3,   15,    6,   14,   14,    7,   25,    0,    4,
        4,    4,    0,   22,   24,    0,    0,   23,    0,   20,
        0,   10,   11,    0,   12,   13,   17,   18,   15,    6,
        5,    6,   14,   14,    0,    0,    0,    4,    4,    4,
       21,    9,   14,    0,    0,    0,    4,    4,    8,    0,
        0,    4,    4,    4,    0,    0,    0,    4,    1,    4,

        4,    0,    1,    0,    0,    4,    2,    0,    2,    0
    } ;

static grecs_dhcpdconst YY_CHAR grecs_dhcpd_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    1,    1,    1,    5,
        5,    8,    1,    5,    9,   10,   11,   12,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   10,   14,    1,
        5,    1,    1,   10,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
        1,   16,    1,    1,   15,    1,   15,   15,   15,   15,

       17,   18,   15,   15,   19,   15,   15,   20,   15,   21,
       15,   15,   15,   15,   22,   15,   15,   15,   15,   15,
       15,   15,   23,    1,    5,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static grecs_dhcpdconst YY_CHAR grecs_dhcpd_meta[24] =
    {   0,
        1,    1,    2,    1,    1,    3,    1,    4,    5,    5,
        5,    5,    5,    1,    5,    1,    5,    5,    5,    5,
        5,    5,    1
    } ;

static grecs_dhcpdconst flex_uint16_t grecs_dhcpd_base[134] =
    {   0,
        0,   22,    0,    0,   22,   24,   23,   28,   29,   30,
      291,  292,   32,  292,  292,   36,  287,    0,  278,   37,
       39,   17,   51,   58,  292,   51,  292,   53,    0,   42,
      292,  292,   59,  292,  292,   62,   69,  292,  292,  285,
      284,  292,    0,   85,   66,  101,  264,   77,  108,  127,
      146,  112,  110,  292,  292,    0,   67,  292,  282,  292,
      111,  292,  292,  119,  292,  292,  292,  292,    0,  281,
      292,    0,  238,  119,  122,  141,  207,  149,  158,  116,
      292,  200,  128,  160,  155,  144,  114,   65,  142,  157,
      139,  166,  170,  142,  133,  171,  130,  172,  292,  176,

      124,  177,  292,  178,  122,  115,  292,   77,  292,  292,
      184,  189,  194,  199,  204,  209,   58,   36,  214,  219,
      224,  229,  234,  239,  241,  243,  248,  253,  258,  263,
      268,  273,  278
    } ;

static grecs_dhcpdconst flex_int16_t grecs_dhcpd_def[134] =
    {   0,
      110,    1,  111,  111,  112,  112,  113,  113,  114,  114,
      110,  110,  110,  110,  110,  115,  116,  117,  117,  118,
      118,   21,  110,  116,  110,  119,  110,  120,  121,  122,
      110,  110,  123,  110,  110,  110,  115,  110,  110,  124,
      116,  110,  125,  110,  126,  126,   46,  110,  110,  116,
      116,  116,  119,  110,  110,  121,  120,  110,  110,  110,
      122,  110,  110,  123,  110,  110,  110,  110,  125,  127,
      110,   44,   46,   46,  110,  110,  110,  116,  116,  116,
      110,   46,   46,  110,  110,  110,  128,  116,   46,  129,
      110,  128,  130,  116,  129,  131,  110,  130,  110,  130,

      132,  131,  110,  131,  133,  132,  110,  133,  110,    0,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110
    } ;

static grecs_dhcpdconst flex_uint16_t grecs_dhcpd_nxt[316] =
    {   0,
       12,   13,   14,   13,   15,   16,   17,   18,   18,   18,
       19,   18,   18,   15,   20,   12,   21,   20,   22,   20,
       20,   20,   15,   23,   27,   31,   27,   28,   24,   28,
       31,   34,   34,   36,   47,   36,   45,   29,   38,   29,
       45,   39,   35,   35,   62,   32,   43,   43,   43,   43,
       32,   40,   48,   54,   36,   58,   55,   49,   46,   50,
       42,   65,   43,   36,   63,   36,   56,   42,   59,   58,
       51,   38,   66,   69,   39,   69,   69,   52,   48,  109,
       36,   94,   59,   49,   40,   70,   70,   71,   70,   70,
       70,   70,   72,   72,   72,   72,   72,   72,   70,   72,

       70,   72,   72,   72,   72,   72,   72,   70,   69,   75,
       69,   69,   54,   62,   42,   55,   42,  107,   42,   93,
       76,   65,   74,   75,  109,   56,  107,   77,   50,   42,
       80,  105,   66,   63,   76,   82,   88,   83,   96,   51,
       73,   77,   84,  101,   42,   89,   52,   78,   42,   73,
       78,   42,   85,   85,   87,   97,   84,   79,   79,   78,
       42,   84,   96,   73,   91,   90,   85,   85,   42,   79,
       79,   93,   99,  103,   99,  100,  104,  100,   99,  103,
      103,  100,  104,  104,   25,   25,   25,   25,   25,   26,
       26,   26,   26,   26,   30,   30,   30,   30,   30,   33,

       33,   33,   33,   33,   37,   37,   37,   37,   37,   41,
       41,   41,   41,   41,   53,   53,   53,   53,   53,   57,
       57,   73,   57,   57,   60,   86,   60,   60,   60,   61,
       61,   61,   61,   61,   64,   64,   64,   64,   64,   67,
       67,   67,   67,   67,   69,   69,   73,   73,   70,   70,
       70,   70,   70,   92,   92,   92,   92,   92,   95,   73,
       95,   95,   95,   98,   98,   98,   98,   98,  102,  102,
      102,  102,  102,  106,  106,  106,  106,  106,  108,  108,
      108,  108,  108,   71,   81,   73,   42,   68,   44,   42,
      110,   11,  110,  110,  110,  110,  110,  110,  110,  110,

      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110
    } ;

static grecs_dhcpdconst flex_int16_t grecs_dhcpd_chk[316] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    5,    7,    6,    5,    2,    6,
        8,    9,   10,   13,   22,   13,   22,    5,   16,    6,
      118,   16,    9,   10,   30,    7,   20,   20,   21,   21,
        8,   16,   23,   26,   23,   28,   26,   23,   21,   24,
       24,   33,  117,   36,   30,   36,   26,   88,   28,   57,
       24,   37,   33,   45,   37,   45,   45,   24,   48,  108,
       48,   88,   57,   48,   37,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   44,   44,   44,   44,   44,

       44,   44,   44,   44,   44,   44,   44,   44,   46,   49,
       46,   46,   53,   61,   52,   53,   87,  106,   80,   87,
       49,   64,   46,   75,  105,   53,  101,   49,   50,   50,
       52,   97,   64,   61,   75,   74,   80,   74,   95,   50,
       74,   75,   76,   94,   94,   83,   50,   51,   51,   83,
       78,   78,   76,   76,   78,   91,   85,   51,   51,   79,
       79,   84,   90,   89,   86,   84,   85,   85,   92,   79,
       79,   92,   93,   96,   98,   93,   96,   98,  100,  102,
      104,  100,  102,  104,  111,  111,  111,  111,  111,  112,
      112,  112,  112,  112,  113,  113,  113,  113,  113,  114,

      114,  114,  114,  114,  115,  115,  115,  115,  115,  116,
      116,  116,  116,  116,  119,  119,  119,  119,  119,  120,
      120,   82,  120,  120,  121,   77,  121,  121,  121,  122,
      122,  122,  122,  122,  123,  123,  123,  123,  123,  124,
      124,  124,  124,  124,  125,  125,  126,  126,  127,  127,
      127,  127,  127,  128,  128,  128,  128,  128,  129,   73,
      129,  129,  129,  130,  130,  130,  130,  130,  131,  131,
      131,  131,  131,  132,  132,  132,  132,  132,  133,  133,
      133,  133,  133,   70,   59,   47,   41,   40,   19,   17,
       11,  110,  110,  110,  110,  110,  110,  110,  110,  110,

      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110
    } ;

static grecs_dhcpd_state_type grecs_dhcpd_last_accepting_state;
static char *grecs_dhcpd_last_accepting_cpos;

extern int grecs_dhcpd_flex_debug;
int grecs_dhcpd_flex_debug = 1;

static grecs_dhcpdconst flex_int16_t grecs_dhcpd_rule_linenum[29] =
    {   0,
       57,   61,   66,   67,   68,   69,   70,   71,   72,   74,
       85,  100,  111,  126,  132,  138,  142,  143,  148,  151,
      152,  154,  155,  156,  161,  163,  164,  165
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define grecs_dhcpdmore() grecs_dhcpdmore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *grecs_dhcpdtext;
#line 1 "dhcpd-lex.l"
/* grecs - Gray's Extensible Configuration System       -*- c -*- */
#define YY_NO_INPUT 1

#line 9 "dhcpd-lex.l"
/* grecs - Gray's Extensible Configuration System
   Copyright (C) 2007-2016 Sergey Poznyakoff

   Grecs is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 3 of the License, or (at your
   option) any later version.

   Grecs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with Grecs. If not, see <http://www.gnu.org/licenses/>. */

#include <grecs.h>
#include <dhcpd-gram.h>
#include <unistd.h>
#include <fcntl.h>
#include <ctype.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/stat.h>
	
#include <wordsplit.h>

#define YY_USER_ACTION do {						\
		if (YYSTATE == 0) {					\
			grecs_dhcpdlloc.beg = grecs_current_locus_point;		\
			grecs_dhcpdlloc.beg.col++;				\
		}							\
  		grecs_current_locus_point.col += grecs_dhcpdleng;		\
 		grecs_dhcpdlloc.end = grecs_current_locus_point;			\
   	} while (0);

#define ISWS(c) ((c)==' '||(c)=='\t')	

#line 714 "dhcpd-lex.c"

#define INITIAL 0
#define COMMENT 1
#define STR 2
#define BOOL 3
#define EXPR 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int grecs_dhcpd_init_globals (void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int grecs_dhcpdlex_destroy (void );

int grecs_dhcpdget_debug (void );

void grecs_dhcpdset_debug (int debug_flag  );

YY_EXTRA_TYPE grecs_dhcpdget_extra (void );

void grecs_dhcpdset_extra (YY_EXTRA_TYPE user_defined  );

FILE *grecs_dhcpdget_in (void );

void grecs_dhcpdset_in  (FILE * _in_str  );

FILE *grecs_dhcpdget_out (void );

void grecs_dhcpdset_out  (FILE * _out_str  );

grecs_dhcpd_size_t grecs_dhcpdget_leng (void );

char *grecs_dhcpdget_text (void );

int grecs_dhcpdget_lineno (void );

void grecs_dhcpdset_lineno (int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int grecs_dhcpdwrap (void );
#else
extern int grecs_dhcpdwrap (void );
#endif
#endif

/* %not-for-header */

#ifndef YY_NO_UNPUT
    
    static void grecs_dhcpdunput (int c,char *buf_ptr  );
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef grecs_dhcpdtext_ptr
static void grecs_dhcpd_flex_strncpy (char *,grecs_dhcpdconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int grecs_dhcpd_flex_strlen (grecs_dhcpdconst char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

#ifdef __cplusplus
static int grecs_dhcpdinput (void );
#else
static int input (void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( grecs_dhcpdtext, grecs_dhcpdleng, 1, grecs_dhcpdout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( grecs_dhcpdin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( grecs_dhcpdin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, grecs_dhcpdin))==0 && ferror(grecs_dhcpdin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(grecs_dhcpdin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "grecs_dhcpdterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef grecs_dhcpdterminate
#define grecs_dhcpdterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) grecs_dhcpd_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-grecs_dhcpddmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int grecs_dhcpdlex (void);

#define YY_DECL int grecs_dhcpdlex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after grecs_dhcpdtext and grecs_dhcpdleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( grecs_dhcpdleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_at_bol = \
				(grecs_dhcpdtext[grecs_dhcpdleng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	grecs_dhcpd_state_type grecs_dhcpd_current_state;
	char *grecs_dhcpd_cp, *grecs_dhcpd_bp;
	int grecs_dhcpd_act;
    
	if ( !(grecs_dhcpd_init) )
		{
		(grecs_dhcpd_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (grecs_dhcpd_start) )
			(grecs_dhcpd_start) = 1;	/* first start state */

		if ( ! grecs_dhcpdin )
/* %if-c-only */
			grecs_dhcpdin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! grecs_dhcpdout )
/* %if-c-only */
			grecs_dhcpdout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			grecs_dhcpdensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				grecs_dhcpd_create_buffer(grecs_dhcpdin,YY_BUF_SIZE );
		}

		grecs_dhcpd_load_buffer_state( );
		}

	{
/* %% [7.0] user's declarations go here */
#line 55 "dhcpd-lex.l"

         /* Line directive */
#line 1009 "dhcpd-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] grecs_dhcpdmore()-related code goes here */
		grecs_dhcpd_cp = (grecs_dhcpd_c_buf_p);

		/* Support of grecs_dhcpdtext. */
		*grecs_dhcpd_cp = (grecs_dhcpd_hold_char);

		/* grecs_dhcpd_bp points to the position in grecs_dhcpd_ch_buf of the start of
		 * the current run.
		 */
		grecs_dhcpd_bp = grecs_dhcpd_cp;

/* %% [9.0] code to set up and find next match goes here */
		grecs_dhcpd_current_state = (grecs_dhcpd_start);
		grecs_dhcpd_current_state += YY_AT_BOL();
grecs_dhcpd_match:
		do
			{
			YY_CHAR grecs_dhcpd_c = grecs_dhcpd_ec[YY_SC_TO_UI(*grecs_dhcpd_cp)] ;
			if ( grecs_dhcpd_accept[grecs_dhcpd_current_state] )
				{
				(grecs_dhcpd_last_accepting_state) = grecs_dhcpd_current_state;
				(grecs_dhcpd_last_accepting_cpos) = grecs_dhcpd_cp;
				}
			while ( grecs_dhcpd_chk[grecs_dhcpd_base[grecs_dhcpd_current_state] + grecs_dhcpd_c] != grecs_dhcpd_current_state )
				{
				grecs_dhcpd_current_state = (int) grecs_dhcpd_def[grecs_dhcpd_current_state];
				if ( grecs_dhcpd_current_state >= 111 )
					grecs_dhcpd_c = grecs_dhcpd_meta[(unsigned int) grecs_dhcpd_c];
				}
			grecs_dhcpd_current_state = grecs_dhcpd_nxt[grecs_dhcpd_base[grecs_dhcpd_current_state] + (unsigned int) grecs_dhcpd_c];
			++grecs_dhcpd_cp;
			}
		while ( grecs_dhcpd_base[grecs_dhcpd_current_state] != 292 );

grecs_dhcpd_find_action:
/* %% [10.0] code to find the action number goes here */
		grecs_dhcpd_act = grecs_dhcpd_accept[grecs_dhcpd_current_state];
		if ( grecs_dhcpd_act == 0 )
			{ /* have to back up */
			grecs_dhcpd_cp = (grecs_dhcpd_last_accepting_cpos);
			grecs_dhcpd_current_state = (grecs_dhcpd_last_accepting_state);
			grecs_dhcpd_act = grecs_dhcpd_accept[grecs_dhcpd_current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for grecs_dhcpdlineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( grecs_dhcpd_flex_debug )
			{
			if ( grecs_dhcpd_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( grecs_dhcpd_act < 29 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)grecs_dhcpd_rule_linenum[grecs_dhcpd_act], grecs_dhcpdtext );
			else if ( grecs_dhcpd_act == 29 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         grecs_dhcpdtext );
			else if ( grecs_dhcpd_act == 30 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( grecs_dhcpd_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*grecs_dhcpd_cp = (grecs_dhcpd_hold_char);
			grecs_dhcpd_cp = (grecs_dhcpd_last_accepting_cpos);
			grecs_dhcpd_current_state = (grecs_dhcpd_last_accepting_state);
			goto grecs_dhcpd_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 57 "dhcpd-lex.l"
{ grecs_parse_line_directive_cpp(grecs_dhcpdtext,
						    &grecs_dhcpdlloc,
						    &grecs_current_locus_point,
						    NULL); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 61 "dhcpd-lex.l"
{ grecs_parse_line_directive(grecs_dhcpdtext,
						    &grecs_dhcpdlloc,
						    &grecs_current_locus_point,
						    NULL); }
	YY_BREAK
/* End-of-line comments */
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 66 "dhcpd-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 67 "dhcpd-lex.l"
/* end-of-file comment */;
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 68 "dhcpd-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 69 "dhcpd-lex.l"
/* end-of-file comment */;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 70 "dhcpd-lex.l"
return DHCPD_IF;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 71 "dhcpd-lex.l"
return DHCPD_ELSIF;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 72 "dhcpd-lex.l"
return DHCPD_ELSE;
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 74 "dhcpd-lex.l"
{
	  char *p;
	  size_t len;
	  for (p = grecs_dhcpdtext, len = grecs_dhcpdleng - 1; ISWS(*p) && len > 0; p++, len--)
                  ;
	  if (len) {
		  grecs_line_add(p, len);
		  grecs_line_add(" ", 1);
	  }
	  grecs_locus_point_advance_line(grecs_current_locus_point);
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 85 "dhcpd-lex.l"
{
	  char *p;
	  size_t len;
	  
	  unput('{');
	  for (p = grecs_dhcpdtext, len = grecs_dhcpdleng - 1; ISWS(*p) && len > 0; p++, len--)
                  ;
	  for (; len > 0 && ISWS(p[len-1]); len--)
	      ;
	  grecs_line_add(p, len);
          BEGIN(INITIAL);
          grecs_dhcpdlval.string = grecs_line_finish();
          return DHCPD_EXPR;     
}
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 100 "dhcpd-lex.l"
{
	  char *p;
	  size_t len;
	  for (p = grecs_dhcpdtext, len = grecs_dhcpdleng - 1; ISWS(*p) && len > 0; p++, len--)
                  ;
	  if (len) {
		  grecs_line_add(p, len);
		  grecs_line_add(" ", 1);
	  }
	  grecs_locus_point_advance_line(grecs_current_locus_point);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 111 "dhcpd-lex.l"
{
	  char *p;
	  size_t len;
	  
	  unput(';');
	  for (p = grecs_dhcpdtext, len = grecs_dhcpdleng - 1; ISWS(*p) && len > 0; p++, len--)
                  ;
	  for (; len > 0 && ISWS(p[len-1]); len--)
	      ;
	  grecs_line_add(p, len);
          BEGIN(INITIAL);
          grecs_dhcpdlval.string = grecs_line_finish();
          return DHCPD_EXPR;     
}
	YY_BREAK
/* Identifiers */
case 14:
YY_RULE_SETUP
#line 126 "dhcpd-lex.l"
{ grecs_line_begin();
	    grecs_line_add(grecs_dhcpdtext, grecs_dhcpdleng);
	    grecs_dhcpdlval.string = grecs_line_finish();
	    return DHCPD_IDENT;
          }
	YY_BREAK
/* Strings */
case 15:
YY_RULE_SETUP
#line 132 "dhcpd-lex.l"
{
	                   grecs_line_begin();
	                   grecs_line_add(grecs_dhcpdtext, grecs_dhcpdleng);
                           grecs_dhcpdlval.string = grecs_line_finish();
                           return DHCPD_STRING; }
	YY_BREAK
/* Quoted strings */
case 16:
YY_RULE_SETUP
#line 138 "dhcpd-lex.l"
{ grecs_line_begin();
                        grecs_line_add(grecs_dhcpdtext + 1, grecs_dhcpdleng - 2);
                        grecs_dhcpdlval.string = grecs_line_finish();
                        return DHCPD_STRING; }
	YY_BREAK
case 17:
#line 143 "dhcpd-lex.l"
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 143 "dhcpd-lex.l"
{ BEGIN(STR);
                         grecs_line_begin();
		         grecs_line_acc_grow_unescape_last(grecs_dhcpdtext + 1,
                                                           grecs_dhcpdleng - 1,
                                                           &grecs_dhcpdlloc); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 148 "dhcpd-lex.l"
{ BEGIN(STR);
                         grecs_line_begin();
		         grecs_line_acc_grow(grecs_dhcpdtext + 1, grecs_dhcpdleng - 1); }
	YY_BREAK
case 20:
#line 152 "dhcpd-lex.l"
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 152 "dhcpd-lex.l"
{ grecs_line_acc_grow_unescape_last(grecs_dhcpdtext, grecs_dhcpdleng, 
                                                          &grecs_dhcpdlloc); }
	YY_BREAK
case 22:
/* rule 22 can match eol */
#line 155 "dhcpd-lex.l"
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 155 "dhcpd-lex.l"
{ grecs_line_acc_grow(grecs_dhcpdtext, grecs_dhcpdleng); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 156 "dhcpd-lex.l"
{ BEGIN(INITIAL);
                        if (grecs_dhcpdleng > 1) 
				grecs_line_add(grecs_dhcpdtext, grecs_dhcpdleng - 1); 
                        grecs_dhcpdlval.string = grecs_line_finish();
		        return DHCPD_STRING; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 161 "dhcpd-lex.l"
;
	YY_BREAK
/* Other tokens */
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 163 "dhcpd-lex.l"
{ grecs_locus_point_advance_line(grecs_current_locus_point); } 
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 164 "dhcpd-lex.l"
return grecs_dhcpdtext[0];
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 165 "dhcpd-lex.l"
{ if (isascii(grecs_dhcpdtext[0]) && isprint(grecs_dhcpdtext[0]))
		grecs_error(&grecs_dhcpdlloc, 0,
			     _("stray character %c"), grecs_dhcpdtext[0]);
           else
                grecs_error(&grecs_dhcpdlloc, 0, _("stray character \\%03o"),
		   	    (unsigned char) grecs_dhcpdtext[0]); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 171 "dhcpd-lex.l"
ECHO;
	YY_BREAK
#line 1322 "dhcpd-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(COMMENT):
case YY_STATE_EOF(STR):
case YY_STATE_EOF(BOOL):
case YY_STATE_EOF(EXPR):
	grecs_dhcpdterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int grecs_dhcpd_amount_of_matched_text = (int) (grecs_dhcpd_cp - (grecs_dhcpdtext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*grecs_dhcpd_cp = (grecs_dhcpd_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed grecs_dhcpdin at a new source and called
			 * grecs_dhcpdlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(grecs_dhcpd_n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_input_file = grecs_dhcpdin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for grecs_dhcpd_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since grecs_dhcpd_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (grecs_dhcpd_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[(grecs_dhcpd_n_chars)] )
			{ /* This was really a NUL. */
			grecs_dhcpd_state_type grecs_dhcpd_next_state;

			(grecs_dhcpd_c_buf_p) = (grecs_dhcpdtext_ptr) + grecs_dhcpd_amount_of_matched_text;

			grecs_dhcpd_current_state = grecs_dhcpd_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * grecs_dhcpd_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			grecs_dhcpd_next_state = grecs_dhcpd_try_NUL_trans( grecs_dhcpd_current_state );

			grecs_dhcpd_bp = (grecs_dhcpdtext_ptr) + YY_MORE_ADJ;

			if ( grecs_dhcpd_next_state )
				{
				/* Consume the NUL. */
				grecs_dhcpd_cp = ++(grecs_dhcpd_c_buf_p);
				grecs_dhcpd_current_state = grecs_dhcpd_next_state;
				goto grecs_dhcpd_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up grecs_dhcpd_cp goes here */
				grecs_dhcpd_cp = (grecs_dhcpd_c_buf_p);
				goto grecs_dhcpd_find_action;
				}
			}

		else switch ( grecs_dhcpd_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(grecs_dhcpd_did_buffer_switch_on_eof) = 0;

				if ( grecs_dhcpdwrap( ) )
					{
					/* Note: because we've taken care in
					 * grecs_dhcpd_get_next_buffer() to have set up
					 * grecs_dhcpdtext, we can now set up
					 * grecs_dhcpd_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(grecs_dhcpd_c_buf_p) = (grecs_dhcpdtext_ptr) + YY_MORE_ADJ;

					grecs_dhcpd_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (grecs_dhcpd_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(grecs_dhcpd_c_buf_p) =
					(grecs_dhcpdtext_ptr) + grecs_dhcpd_amount_of_matched_text;

				grecs_dhcpd_current_state = grecs_dhcpd_get_previous_state(  );

				grecs_dhcpd_cp = (grecs_dhcpd_c_buf_p);
				grecs_dhcpd_bp = (grecs_dhcpdtext_ptr) + YY_MORE_ADJ;
				goto grecs_dhcpd_match;

			case EOB_ACT_LAST_MATCH:
				(grecs_dhcpd_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[(grecs_dhcpd_n_chars)];

				grecs_dhcpd_current_state = grecs_dhcpd_get_previous_state(  );

				grecs_dhcpd_cp = (grecs_dhcpd_c_buf_p);
				grecs_dhcpd_bp = (grecs_dhcpdtext_ptr) + YY_MORE_ADJ;
				goto grecs_dhcpd_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of grecs_dhcpdlex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

/* grecs_dhcpd_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int grecs_dhcpd_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf;
	char *source = (grecs_dhcpdtext_ptr);
	grecs_dhcpd_size_t number_to_move, i;
	int ret_val;

	if ( (grecs_dhcpd_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[(grecs_dhcpd_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (grecs_dhcpd_c_buf_p) - (grecs_dhcpdtext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (grecs_dhcpd_size_t) ((grecs_dhcpd_c_buf_p) - (grecs_dhcpdtext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars = (grecs_dhcpd_n_chars) = 0;

	else
		{
			grecs_dhcpd_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int grecs_dhcpd_c_buf_p_offset =
				(int) ((grecs_dhcpd_c_buf_p) - b->grecs_dhcpd_ch_buf);

			if ( b->grecs_dhcpd_is_our_buffer )
				{
				grecs_dhcpd_size_t new_size = b->grecs_dhcpd_buf_size * 2;

				if ( new_size <= 0 )
					b->grecs_dhcpd_buf_size += b->grecs_dhcpd_buf_size / 8;
				else
					b->grecs_dhcpd_buf_size *= 2;

				b->grecs_dhcpd_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					grecs_dhcpdrealloc((void *) b->grecs_dhcpd_ch_buf,b->grecs_dhcpd_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->grecs_dhcpd_ch_buf = 0;

			if ( ! b->grecs_dhcpd_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(grecs_dhcpd_c_buf_p) = &b->grecs_dhcpd_ch_buf[grecs_dhcpd_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[number_to_move]),
			(grecs_dhcpd_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars = (grecs_dhcpd_n_chars);
		}

	if ( (grecs_dhcpd_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			grecs_dhcpdrestart(grecs_dhcpdin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((grecs_dhcpd_size_t) ((grecs_dhcpd_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		grecs_dhcpd_size_t new_size = (grecs_dhcpd_n_chars) + number_to_move + ((grecs_dhcpd_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf = (char *) grecs_dhcpdrealloc((void *) YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpd_get_next_buffer()" );
	}

	(grecs_dhcpd_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[(grecs_dhcpd_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[(grecs_dhcpd_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(grecs_dhcpdtext_ptr) = &YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[0];

	return ret_val;
}

/* grecs_dhcpd_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

    static grecs_dhcpd_state_type grecs_dhcpd_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	grecs_dhcpd_state_type grecs_dhcpd_current_state;
	char *grecs_dhcpd_cp;
    
/* %% [15.0] code to get the start state into grecs_dhcpd_current_state goes here */
	grecs_dhcpd_current_state = (grecs_dhcpd_start);
	grecs_dhcpd_current_state += YY_AT_BOL();

	for ( grecs_dhcpd_cp = (grecs_dhcpdtext_ptr) + YY_MORE_ADJ; grecs_dhcpd_cp < (grecs_dhcpd_c_buf_p); ++grecs_dhcpd_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR grecs_dhcpd_c = (*grecs_dhcpd_cp ? grecs_dhcpd_ec[YY_SC_TO_UI(*grecs_dhcpd_cp)] : 1);
		if ( grecs_dhcpd_accept[grecs_dhcpd_current_state] )
			{
			(grecs_dhcpd_last_accepting_state) = grecs_dhcpd_current_state;
			(grecs_dhcpd_last_accepting_cpos) = grecs_dhcpd_cp;
			}
		while ( grecs_dhcpd_chk[grecs_dhcpd_base[grecs_dhcpd_current_state] + grecs_dhcpd_c] != grecs_dhcpd_current_state )
			{
			grecs_dhcpd_current_state = (int) grecs_dhcpd_def[grecs_dhcpd_current_state];
			if ( grecs_dhcpd_current_state >= 111 )
				grecs_dhcpd_c = grecs_dhcpd_meta[(unsigned int) grecs_dhcpd_c];
			}
		grecs_dhcpd_current_state = grecs_dhcpd_nxt[grecs_dhcpd_base[grecs_dhcpd_current_state] + (unsigned int) grecs_dhcpd_c];
		}

	return grecs_dhcpd_current_state;
}

/* grecs_dhcpd_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = grecs_dhcpd_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static grecs_dhcpd_state_type grecs_dhcpd_try_NUL_trans  (grecs_dhcpd_state_type grecs_dhcpd_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int grecs_dhcpd_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *grecs_dhcpd_cp = (grecs_dhcpd_c_buf_p);

	YY_CHAR grecs_dhcpd_c = 1;
	if ( grecs_dhcpd_accept[grecs_dhcpd_current_state] )
		{
		(grecs_dhcpd_last_accepting_state) = grecs_dhcpd_current_state;
		(grecs_dhcpd_last_accepting_cpos) = grecs_dhcpd_cp;
		}
	while ( grecs_dhcpd_chk[grecs_dhcpd_base[grecs_dhcpd_current_state] + grecs_dhcpd_c] != grecs_dhcpd_current_state )
		{
		grecs_dhcpd_current_state = (int) grecs_dhcpd_def[grecs_dhcpd_current_state];
		if ( grecs_dhcpd_current_state >= 111 )
			grecs_dhcpd_c = grecs_dhcpd_meta[(unsigned int) grecs_dhcpd_c];
		}
	grecs_dhcpd_current_state = grecs_dhcpd_nxt[grecs_dhcpd_base[grecs_dhcpd_current_state] + (unsigned int) grecs_dhcpd_c];
	grecs_dhcpd_is_jam = (grecs_dhcpd_current_state == 110);

		return grecs_dhcpd_is_jam ? 0 : grecs_dhcpd_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void grecs_dhcpdunput (int c, char * grecs_dhcpd_bp )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *grecs_dhcpd_cp;
    
    grecs_dhcpd_cp = (grecs_dhcpd_c_buf_p);

	/* undo effects of setting up grecs_dhcpdtext */
	*grecs_dhcpd_cp = (grecs_dhcpd_hold_char);

	if ( grecs_dhcpd_cp < YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		grecs_dhcpd_size_t number_to_move = (grecs_dhcpd_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf )
			*--dest = *--source;

		grecs_dhcpd_cp += (int) (dest - source);
		grecs_dhcpd_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars =
			(grecs_dhcpd_n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_size;

		if ( grecs_dhcpd_cp < YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--grecs_dhcpd_cp = (char) c;

/* %% [18.0] update grecs_dhcpdlineno here */

	(grecs_dhcpdtext_ptr) = grecs_dhcpd_bp;
	(grecs_dhcpd_hold_char) = *grecs_dhcpd_cp;
	(grecs_dhcpd_c_buf_p) = grecs_dhcpd_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int grecs_dhcpdinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(grecs_dhcpd_c_buf_p) = (grecs_dhcpd_hold_char);

	if ( *(grecs_dhcpd_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* grecs_dhcpd_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (grecs_dhcpd_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_ch_buf[(grecs_dhcpd_n_chars)] )
			/* This was really a NUL. */
			*(grecs_dhcpd_c_buf_p) = '\0';

		else
			{ /* need more input */
			grecs_dhcpd_size_t offset = (grecs_dhcpd_c_buf_p) - (grecs_dhcpdtext_ptr);
			++(grecs_dhcpd_c_buf_p);

			switch ( grecs_dhcpd_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because grecs_dhcpd_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					grecs_dhcpdrestart(grecs_dhcpdin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( grecs_dhcpdwrap( ) )
						return EOF;

					if ( ! (grecs_dhcpd_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return grecs_dhcpdinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(grecs_dhcpd_c_buf_p) = (grecs_dhcpdtext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (grecs_dhcpd_c_buf_p);	/* cast for 8-bit char's */
	*(grecs_dhcpd_c_buf_p) = '\0';	/* preserve grecs_dhcpdtext */
	(grecs_dhcpd_hold_char) = *++(grecs_dhcpd_c_buf_p);

/* %% [19.0] update BOL and grecs_dhcpdlineno */
	YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void grecs_dhcpdrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        grecs_dhcpdensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            grecs_dhcpd_create_buffer(grecs_dhcpdin,YY_BUF_SIZE );
	}

	grecs_dhcpd_init_buffer(YY_CURRENT_BUFFER,input_file );
	grecs_dhcpd_load_buffer_state( );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void grecs_dhcpd_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		grecs_dhcpdpop_buffer_state();
	 *		grecs_dhcpdpush_buffer_state(new_buffer);
     */
	grecs_dhcpdensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_dhcpd_c_buf_p) = (grecs_dhcpd_hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_pos = (grecs_dhcpd_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars = (grecs_dhcpd_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	grecs_dhcpd_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (grecs_dhcpdwrap()) processing, but the only time this flag
	 * is looked at is after grecs_dhcpdwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(grecs_dhcpd_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void grecs_dhcpd_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(grecs_dhcpd_n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars;
	(grecs_dhcpdtext_ptr) = (grecs_dhcpd_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_pos;
/* %if-c-only */
	grecs_dhcpdin = YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(grecs_dhcpd_hold_char) = *(grecs_dhcpd_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE grecs_dhcpd_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) grecs_dhcpdalloc(sizeof( struct grecs_dhcpd_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpd_create_buffer()" );

	b->grecs_dhcpd_buf_size = (grecs_dhcpd_size_t)size;

	/* grecs_dhcpd_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->grecs_dhcpd_ch_buf = (char *) grecs_dhcpdalloc(b->grecs_dhcpd_buf_size + 2  );
	if ( ! b->grecs_dhcpd_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpd_create_buffer()" );

	b->grecs_dhcpd_is_our_buffer = 1;

	grecs_dhcpd_init_buffer(b,file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with grecs_dhcpd_create_buffer()
 * 
 */
/* %if-c-only */
    void grecs_dhcpd_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->grecs_dhcpd_is_our_buffer )
		grecs_dhcpdfree((void *) b->grecs_dhcpd_ch_buf  );

	grecs_dhcpdfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a grecs_dhcpdrestart() or at EOF.
 */
/* %if-c-only */
    static void grecs_dhcpd_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	grecs_dhcpd_flush_buffer(b );

/* %if-c-only */
	b->grecs_dhcpd_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->grecs_dhcpd_fill_buffer = 1;

    /* If b is the current buffer, then grecs_dhcpd_init_buffer was _probably_
     * called from grecs_dhcpdrestart() or through grecs_dhcpd_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->grecs_dhcpd_bs_lineno = 1;
        b->grecs_dhcpd_bs_column = 0;
    }

/* %if-c-only */

        b->grecs_dhcpd_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void grecs_dhcpd_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->grecs_dhcpd_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->grecs_dhcpd_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->grecs_dhcpd_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->grecs_dhcpd_buf_pos = &b->grecs_dhcpd_ch_buf[0];

	b->grecs_dhcpd_at_bol = 1;
	b->grecs_dhcpd_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		grecs_dhcpd_load_buffer_state( );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void grecs_dhcpdpush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	grecs_dhcpdensure_buffer_stack();

	/* This block is copied from grecs_dhcpd_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_dhcpd_c_buf_p) = (grecs_dhcpd_hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_buf_pos = (grecs_dhcpd_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_dhcpd_n_chars = (grecs_dhcpd_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(grecs_dhcpd_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from grecs_dhcpd_switch_to_buffer. */
	grecs_dhcpd_load_buffer_state( );
	(grecs_dhcpd_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void grecs_dhcpdpop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	grecs_dhcpd_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((grecs_dhcpd_buffer_stack_top) > 0)
		--(grecs_dhcpd_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		grecs_dhcpd_load_buffer_state( );
		(grecs_dhcpd_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void grecs_dhcpdensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	grecs_dhcpd_size_t num_to_alloc;
    
	if (!(grecs_dhcpd_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; // After all that talk, this was set to 1 anyways...
		(grecs_dhcpd_buffer_stack) = (struct grecs_dhcpd_buffer_state**)grecs_dhcpdalloc
								(num_to_alloc * sizeof(struct grecs_dhcpd_buffer_state*)
								);
		if ( ! (grecs_dhcpd_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpdensure_buffer_stack()" );
								  
		memset((grecs_dhcpd_buffer_stack), 0, num_to_alloc * sizeof(struct grecs_dhcpd_buffer_state*));
				
		(grecs_dhcpd_buffer_stack_max) = num_to_alloc;
		(grecs_dhcpd_buffer_stack_top) = 0;
		return;
	}

	if ((grecs_dhcpd_buffer_stack_top) >= ((grecs_dhcpd_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		grecs_dhcpd_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (grecs_dhcpd_buffer_stack_max) + grow_size;
		(grecs_dhcpd_buffer_stack) = (struct grecs_dhcpd_buffer_state**)grecs_dhcpdrealloc
								((grecs_dhcpd_buffer_stack),
								num_to_alloc * sizeof(struct grecs_dhcpd_buffer_state*)
								);
		if ( ! (grecs_dhcpd_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpdensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((grecs_dhcpd_buffer_stack) + (grecs_dhcpd_buffer_stack_max), 0, grow_size * sizeof(struct grecs_dhcpd_buffer_state*));
		(grecs_dhcpd_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE grecs_dhcpd_scan_buffer  (char * base, grecs_dhcpd_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) grecs_dhcpdalloc(sizeof( struct grecs_dhcpd_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpd_scan_buffer()" );

	b->grecs_dhcpd_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->grecs_dhcpd_buf_pos = b->grecs_dhcpd_ch_buf = base;
	b->grecs_dhcpd_is_our_buffer = 0;
	b->grecs_dhcpd_input_file = 0;
	b->grecs_dhcpd_n_chars = b->grecs_dhcpd_buf_size;
	b->grecs_dhcpd_is_interactive = 0;
	b->grecs_dhcpd_at_bol = 1;
	b->grecs_dhcpd_fill_buffer = 0;
	b->grecs_dhcpd_buffer_status = YY_BUFFER_NEW;

	grecs_dhcpd_switch_to_buffer(b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to grecs_dhcpdlex() will
 * scan from a @e copy of @a str.
 * @param grecs_dhcpdstr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       grecs_dhcpd_scan_bytes() instead.
 */
YY_BUFFER_STATE grecs_dhcpd_scan_string (grecs_dhcpdconst char * grecs_dhcpdstr )
{
    
	return grecs_dhcpd_scan_bytes(grecs_dhcpdstr,strlen(grecs_dhcpdstr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to grecs_dhcpdlex() will
 * scan from a @e copy of @a bytes.
 * @param grecs_dhcpdbytes the byte buffer to scan
 * @param _grecs_dhcpdbytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE grecs_dhcpd_scan_bytes  (grecs_dhcpdconst char * grecs_dhcpdbytes, grecs_dhcpd_size_t  _grecs_dhcpdbytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	grecs_dhcpd_size_t n;
	grecs_dhcpd_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _grecs_dhcpdbytes_len + 2;
	buf = (char *) grecs_dhcpdalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_dhcpd_scan_bytes()" );

	for ( i = 0; i < _grecs_dhcpdbytes_len; ++i )
		buf[i] = grecs_dhcpdbytes[i];

	buf[_grecs_dhcpdbytes_len] = buf[_grecs_dhcpdbytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = grecs_dhcpd_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in grecs_dhcpd_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->grecs_dhcpd_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void grecs_dhcpd_fatal_error (grecs_dhcpdconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine grecs_dhcpdless() so it works in section 3 code. */

#undef grecs_dhcpdless
#define grecs_dhcpdless(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_dhcpdtext. */ \
        int grecs_dhcpdless_macro_arg = (n); \
        YY_LESS_LINENO(grecs_dhcpdless_macro_arg);\
		grecs_dhcpdtext[grecs_dhcpdleng] = (grecs_dhcpd_hold_char); \
		(grecs_dhcpd_c_buf_p) = grecs_dhcpdtext + grecs_dhcpdless_macro_arg; \
		(grecs_dhcpd_hold_char) = *(grecs_dhcpd_c_buf_p); \
		*(grecs_dhcpd_c_buf_p) = '\0'; \
		grecs_dhcpdleng = grecs_dhcpdless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int grecs_dhcpdget_lineno  (void)
{
        
    return grecs_dhcpdlineno;
}

/** Get the input stream.
 * 
 */
FILE *grecs_dhcpdget_in  (void)
{
        return grecs_dhcpdin;
}

/** Get the output stream.
 * 
 */
FILE *grecs_dhcpdget_out  (void)
{
        return grecs_dhcpdout;
}

/** Get the length of the current token.
 * 
 */
grecs_dhcpd_size_t grecs_dhcpdget_leng  (void)
{
        return grecs_dhcpdleng;
}

/** Get the current token.
 * 
 */

char *grecs_dhcpdget_text  (void)
{
        return grecs_dhcpdtext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void grecs_dhcpdset_lineno (int  _line_number )
{
    
    grecs_dhcpdlineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see grecs_dhcpd_switch_to_buffer
 */
void grecs_dhcpdset_in (FILE *  _in_str )
{
        grecs_dhcpdin = _in_str ;
}

void grecs_dhcpdset_out (FILE *  _out_str )
{
        grecs_dhcpdout = _out_str ;
}

int grecs_dhcpdget_debug  (void)
{
        return grecs_dhcpd_flex_debug;
}

void grecs_dhcpdset_debug (int  _bdebug )
{
        grecs_dhcpd_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int grecs_dhcpd_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from grecs_dhcpdlex_destroy(), so don't allocate here.
     */

    (grecs_dhcpd_buffer_stack) = 0;
    (grecs_dhcpd_buffer_stack_top) = 0;
    (grecs_dhcpd_buffer_stack_max) = 0;
    (grecs_dhcpd_c_buf_p) = (char *) 0;
    (grecs_dhcpd_init) = 0;
    (grecs_dhcpd_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    grecs_dhcpdin = stdin;
    grecs_dhcpdout = stdout;
#else
    grecs_dhcpdin = (FILE *) 0;
    grecs_dhcpdout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * grecs_dhcpdlex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* grecs_dhcpdlex_destroy is for both reentrant and non-reentrant scanners. */
int grecs_dhcpdlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		grecs_dhcpd_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		grecs_dhcpdpop_buffer_state();
	}

	/* Destroy the stack itself. */
	grecs_dhcpdfree((grecs_dhcpd_buffer_stack) );
	(grecs_dhcpd_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * grecs_dhcpdlex() is called, initialization will occur. */
    grecs_dhcpd_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef grecs_dhcpdtext_ptr
static void grecs_dhcpd_flex_strncpy (char* s1, grecs_dhcpdconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int grecs_dhcpd_flex_strlen (grecs_dhcpdconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *grecs_dhcpdalloc (grecs_dhcpd_size_t  size )
{
			return (void *) malloc( size );
}

void *grecs_dhcpdrealloc  (void * ptr, grecs_dhcpd_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void grecs_dhcpdfree (void * ptr )
{
			free( (char *) ptr );	/* see grecs_dhcpdrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-grecs_dhcpdtables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "grecs_dhcpdtables"
/* %endif */

/* %ok-for-header */

#line 171 "dhcpd-lex.l"



void
grecs_dhcpd_begin_bool(void)
{
        BEGIN(BOOL);
}

void
grecs_dhcpd_begin_expr(void)
{
        BEGIN(EXPR);
}

struct dhcpd_input_context {
	ino_t i_node;
	dev_t i_dev;
        struct grecs_locus_point point;
	grecs_locus_t locus;		/* Current input location */
	YY_BUFFER_STATE state;
	FILE *input;
};

static struct grecs_list *input_stack;
static ino_t i_node;
static dev_t i_dev;

static void
free_context(void *ptr)
{
	free(ptr);
}

static int
cmp_context(const void *a, const void *b)
{
	struct dhcpd_input_context const *ac = a;
	struct dhcpd_input_context const *bc = b;

	return !(ac->i_node == bc->i_node && ac->i_dev == bc->i_dev);
}

static int
_push_context(const char *name, ino_t i_node, dev_t i_dev, grecs_locus_t *loc)
{
	struct dhcpd_input_context ctx, *pctx;
	
	if (!input_stack) {
		input_stack = grecs_list_create();
		input_stack->free_entry = free_context;
		input_stack->cmp = cmp_context;
	} else {
		ctx.i_dev = i_dev;
		ctx.i_node = i_node;
		pctx = grecs_list_locate(input_stack, &ctx);
		if (pctx) {
			grecs_error(&grecs_dhcpdlloc, 0,
				    _("%s has already been included"), name);
			grecs_error(&pctx->locus, 0,
			    _("this is where the previous inclusion occurred"));
			return 1;
		}

		pctx = grecs_malloc(sizeof(*pctx));
		pctx->i_node = i_node;
		pctx->i_dev = i_dev;
                if (loc)
                        pctx->locus = *loc;
                else
                        memset(&pctx->locus, 0, sizeof(pctx->locus)); /* FIXME */
		pctx->point = grecs_current_locus_point;
		pctx->state = YY_CURRENT_BUFFER;
		pctx->input = grecs_dhcpdin;
		grecs_list_push(input_stack, pctx);
	}
	return 0;
}

static int
_pop_context()
{
	struct dhcpd_input_context *pctx;

	if (!grecs_dhcpdin)
		return 1;
        if (grecs_preprocessor)
                pclose(grecs_dhcpdin);
        else
	        fclose(grecs_dhcpdin);
	pctx = grecs_list_pop(input_stack);
	if (!pctx) {
		grecs_dhcpdin = NULL;
		return 1;
	}
	i_node = pctx->i_node;
	i_dev = pctx->i_dev;
	grecs_current_locus_point = pctx->point;
	grecs_dhcpdin = pctx->input;
	grecs_dhcpd_delete_buffer(YY_CURRENT_BUFFER);
	grecs_dhcpd_switch_to_buffer(pctx->state);
	grecs_free(pctx);
	return 0;
}

int
grecs_dhcpdwrap()
{
	return _pop_context();
}

int
grecs_dhcpd_new_source(const char *name, grecs_locus_t *loc)
{
	struct stat st;
	FILE *fp;
	
	if (access(name, F_OK)) {
		int ec = errno;
		char *tmp = grecs_find_include_file(name, 0);
		if (!tmp) {
			grecs_error(loc, ec, _("cannot open `%s'"), name);
			return 1;
		}
		name = grecs_install_text(tmp);
		free(tmp);
	}
	
	fp = fopen(name, "r");
	if (!fp) {
		grecs_error(loc, errno, _("cannot open `%s'"), name);
		return 1;
 	}
	if (fstat(fileno(fp), &st)) {
		grecs_error(loc, errno, _("can't state %s"), name);
		fclose(fp);
		return 1;
	}
        if (grecs_preprocessor) {
                char *cmd = NULL;
                size_t size = 0;

		fclose(fp);
                if (grecs_asprintf(&cmd, &size, "%s \"%s\"",
                                   grecs_preprocessor, name))
                        grecs_alloc_die();
              
                fp = popen(cmd, "r");
                if (!fp) {
		        grecs_error(loc, errno, _("cannot open `%s'"), cmd);
                        grecs_free(cmd);
                        return 1;
                }
                grecs_free(cmd);
        }

	if (_push_context(name, st.st_ino, st.st_dev, loc)) {
		return 1;
	}
	i_node = st.st_ino;
	i_dev = st.st_dev;
	grecs_dhcpdin = fp;
	grecs_dhcpd_switch_to_buffer(grecs_dhcpd_create_buffer(grecs_dhcpdin,YY_BUF_SIZE));
	grecs_current_locus_point.file = grecs_install_text(name);
	grecs_current_locus_point.line = 1;
	grecs_current_locus_point.col = 0;
	return 0;
}

void
grecs_dhcpd_close_sources()
{
	while (!_pop_context())
		;
	grecs_list_free(input_stack);
	input_stack = NULL;
}

